==> druid-integration-tests-0.17.0-sources.jar: org/apache/druid/testing/utils/TestQueryHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.testing.utils;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.inject.Inject;
import org.apache.druid.java.util.common.StringUtils;
import org.apache.druid.testing.IntegrationTestingConfig;
import org.apache.druid.testing.clients.QueryResourceTestClient;

public class TestQueryHelper extends AbstractTestQueryHelper<QueryWithResults>
{

  @Inject
  TestQueryHelper(
      ObjectMapper jsonMapper,
      QueryResourceTestClient queryClient,
      IntegrationTestingConfig config
  )
  {
    super(jsonMapper, queryClient, config);
  }

  @Override
  public void testQueriesFromFile(String filePath, int timesToRun) throws Exception
  {
    testQueriesFromFile(getQueryURL(broker), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(brokerTLS), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(router), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(routerTLS), filePath, timesToRun);
  }

  public void testQueriesFromString(String str, int timesToRun) throws Exception
  {
    testQueriesFromString(getQueryURL(broker), str, timesToRun);
    testQueriesFromString(getQueryURL(brokerTLS), str, timesToRun);
    testQueriesFromString(getQueryURL(router), str, timesToRun);
    testQueriesFromString(getQueryURL(routerTLS), str, timesToRun);
  }


  @Override
  protected String getQueryURL(String schemeAndHost)
  {
    return StringUtils.format("%s/druid/v2?pretty", schemeAndHost);
  }

}

==> druid-integration-tests-0.19.0-sources.jar: org/apache/druid/testing/utils/TestQueryHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.testing.utils;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.inject.Inject;
import org.apache.druid.java.util.common.StringUtils;
import org.apache.druid.testing.IntegrationTestingConfig;
import org.apache.druid.testing.clients.QueryResourceTestClient;

public class TestQueryHelper extends AbstractTestQueryHelper<QueryWithResults>
{

  @Inject
  TestQueryHelper(
      ObjectMapper jsonMapper,
      QueryResourceTestClient queryClient,
      IntegrationTestingConfig config
  )
  {
    super(jsonMapper, queryClient, config);
  }

  @Override
  public void testQueriesFromFile(String filePath, int timesToRun) throws Exception
  {
    testQueriesFromFile(getQueryURL(broker), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(brokerTLS), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(router), filePath, timesToRun);
    testQueriesFromFile(getQueryURL(routerTLS), filePath, timesToRun);
  }

  public void testQueriesFromString(String str, int timesToRun) throws Exception
  {
    testQueriesFromString(getQueryURL(broker), str, timesToRun);
    testQueriesFromString(getQueryURL(brokerTLS), str, timesToRun);
    testQueriesFromString(getQueryURL(router), str, timesToRun);
    testQueriesFromString(getQueryURL(routerTLS), str, timesToRun);
  }


  @Override
  public String getQueryURL(String schemeAndHost)
  {
    return StringUtils.format("%s/druid/v2?pretty", schemeAndHost);
  }

}
